==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24MaximizeAction.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$MaximizeAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 5cf595c885f13646 javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24MaximizeAction.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$MaximizeAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 5cf595c885f13646 javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MaximizeAction_H_ */
